==> solutions_template-1.9.0-py3-none-any.whl: solutions_template/modules/terraform_gke/terraform/stages/2-gke/variables.tf <==
/**
 * Copyright 2022 Google LLC
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 */

variable "project_id" {
  type        = string
  description = "GCP Project ID"

  validation {
    condition     = length(var.project_id) > 0
    error_message = "The project_id value must be an non-empty string."
  }
}

variable "region" {
  type        = string
  description = "Default GCP region"
  default     = "us-central1"

  validation {
    condition     = length(var.region) > 0
    error_message = "The region value must be an non-empty string."
  }
}

variable "cluster_name" {
  type    = string
  default = "main-cluster"
}

variable "kubernetes_version" {
  type        = string
  description = "Kubernetes version. See https://cloud.google.com/kubernetes-engine/docs/release-notes-stable"
}

variable "machine_type" {
  type        = string
  description = "VM machine time"
  default     = "n1-standard-4"
}

variable "cert_issuer_email" {
  type        = string
  description = "Cert Issuer Email"
}

variable "api_domain" {
  type        = string
  description = "API endpoint domain, excluding protocol"
  default     = "localhost"
}

==> solutions_template-1.10.0-py3-none-any.whl: solutions_template/modules/terraform_gke/terraform/stages/2-gke/variables.tf <==
/**
 * Copyright 2022 Google LLC
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 */

variable "project_id" {
  type        = string
  description = "GCP Project ID"

  validation {
    condition     = length(var.project_id) > 0
    error_message = "The project_id value must be an non-empty string."
  }
}

variable "region" {
  type        = string
  description = "Default GCP region"
  default     = "us-central1"

  validation {
    condition     = length(var.region) > 0
    error_message = "The region value must be an non-empty string."
  }
}

variable "cluster_name" {
  type    = string
  default = "main-cluster"
}

variable "kubernetes_version" {
  type        = string
  description = "Kubernetes version. See https://cloud.google.com/kubernetes-engine/docs/release-notes-stable"
}

variable "node_machine_type" {
  type        = string
  description = "VM machine time"
  default     = "n1-standard-4"
}

variable "private_cluster" {
  type        = bool
  description = "Whether to use private nodes"
  default     = true
}
